function [mu,rho,sigma]=markovchainstats(s,P)
% MarkovChainStats - Properties of discrete Markov Chain
%
% [mu,rho,sigma]=markovchainstats(s,P)
%
% Input: s -   (nx1) vector of states
%        P -   (nxn) right stochastic matrix (COLUMNS sum to one!):
%              the prob. of reaching state j from state i is P(i,j).
%
% Output: mu    - unconditional mean
%         rho   - autocorrelation coef.
%         sigma - std. dev.
%
% Author: Marco Maffezzoli. Ver. 1.0.0, 11/2012.
%

dist=ergodicdist(P,2);
Pinv=dist(:,ones(1,size(P,2)));
mu=s'*dist;
ac=sum(sum(P'.*Pinv.*((s-mu)*(s-mu)')));
v=((s-mu).^2)'*dist;
rho=ac/v;
sigma=sqrt(v);